@@ -11,5 +11,5 @@
 #import "JPUSHService.h"
 
 @interface AppDelegate (JPush) <JPUSHRegisterDelegate>
--(void)registerForIos10RemoteNotification;
+-(void)registerForRemoteNotification;
 @end
